@@ -83,7 +83,8 @@
               webchat_url |
               pubsub |
               changesubject |
-              avatarhash]) -> [xdata_field()].
+              avatarhash |
+              'hats#hash']) -> [xdata_field()].
 
 dec_int(Val) -> dec_int(Val, infinity, infinity).
 
@@ -276,6 +277,10 @@ encode(List, Lang, Required) ->
                   [encode_avatarhash(Val,
                                      Lang,
                                      lists:member(avatarhash, Required))];
+              {'hats#hash', Val} ->
+                  ['encode_hats#hash'(Val,
+                                      Lang,
+                                      lists:member('hats#hash', Required))];
               #xdata_field{} -> [Opt]
           end
           || Opt <- List],
@@ -885,6 +890,36 @@ do_decode([#xdata_field{var =
                            <<"muc#roominfo_avatarhash">>,
                            XMLNS}})
     end;
+do_decode([#xdata_field{var = <<"hats#hash">>,
+                        values = [Value]}
+           | Fs],
+          XMLNS, Required, Acc) ->
+    try Value of
+        Result ->
+            do_decode(Fs,
+                      XMLNS,
+                      lists:delete(<<"hats#hash">>, Required),
+                      [{'hats#hash', Result} | Acc])
+    catch
+        _:_ ->
+            erlang:error({?MODULE,
+                          {bad_var_value, <<"hats#hash">>, XMLNS}})
+    end;
+do_decode([#xdata_field{var = <<"hats#hash">>,
+                        values = []} =
+               F
+           | Fs],
+          XMLNS, Required, Acc) ->
+    do_decode([F#xdata_field{var = <<"hats#hash">>,
+                             values = [<<>>]}
+               | Fs],
+              XMLNS,
+              Required,
+              Acc);
+do_decode([#xdata_field{var = <<"hats#hash">>} | _],
+          XMLNS, _, _) ->
+    erlang:error({?MODULE,
+                  {too_many_values, <<"hats#hash">>, XMLNS}});
 do_decode([#xdata_field{var = Var} | Fs], XMLNS,
           Required, Acc) ->
     if Var /= <<"FORM_TYPE">> ->
@@ -1189,3 +1224,20 @@ encode_avatarhash(Value, Lang, IsRequired) ->
                      xmpp_tr:tr(Lang,
                                 ?T("Hash of the vCard-temp avatar of this "
                                    "room"))}.
+
+-spec 'encode_hats#hash'(binary(), binary(),
+                         boolean()) -> xdata_field().
+
+'encode_hats#hash'(Value, Lang, IsRequired) ->
+    Values = case Value of
+                 <<>> -> [];
+                 Value -> [Value]
+             end,
+    Opts = [],
+    #xdata_field{var = <<"hats#hash">>, values = Values,
+                 required = IsRequired, type = 'text-single',
+                 options = Opts, desc = <<>>,
+                 label =
+                     xmpp_tr:tr(Lang,
+                                ?T("Hash computed from the list of hats "
+                                   "available in a room"))}.
