@@ -346,22 +346,9 @@ get_mod(<<"pubsub">>,
         <<"http://jabber.org/protocol/pubsub">>) ->
     xep0060;
 get_mod(<<"tzo">>, <<"urn:xmpp:time">>) -> xep0202;
-get_mod(<<"presence-out">>, <<"jabber:iq:privacy">>) ->
-    xep0016;
-get_mod(<<"mechanism-too-weak">>,
-        <<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
-    rfc6120;
-get_mod(<<"improper-addressing">>,
-        <<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
-    rfc6120;
-get_mod(<<"r">>, <<"urn:xmpp:sm:3">>) -> xep0198;
-get_mod(<<"submission-id">>,
-        <<"urn:xmpp:mix:core:0">>) ->
-    xep0369;
 get_mod(<<"unsupported-info">>,
         <<"urn:xmpp:jingle:errors:1">>) ->
     xep0166;
-get_mod(<<"text">>, <<"urn:xmpp:sasl:2">>) -> xep0388;
 get_mod(<<"query">>, <<"jabber:iq:version">>) ->
     xep0092;
 get_mod(<<"archived">>, <<"urn:xmpp:mam:tmp">>) ->
@@ -479,8 +466,6 @@ get_mod(<<"no-permanent-storage">>,
 get_mod(<<"unsupported-applications">>,
         <<"urn:xmpp:jingle:1">>) ->
     xep0166;
-get_mod(<<"text">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"credentials-expired">>,
         <<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
     rfc6120;
@@ -737,6 +722,8 @@ get_mod(<<"close">>,
     xep0047;
 get_mod(<<"x509-csr">>, <<"urn:xmpp:x509:0">>) ->
     xep0417;
+get_mod(<<"report">>, <<"urn:xmpp:reporting:1">>) ->
+    xep0377;
 get_mod(<<"internal-server-error">>,
         <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -766,6 +753,9 @@ get_mod(<<"method">>,
 get_mod(<<"invalid-jid">>,
         <<"http://jabber.org/protocol/pubsub#errors">>) ->
     xep0060;
+get_mod(<<"message">>,
+        <<"urn:xmpp:http:upload:purpose:0">>) ->
+    xep0363;
 get_mod(<<"reason">>,
         <<"urn:xmpp:message-moderate:1">>) ->
     xep0425;
@@ -946,8 +936,6 @@ get_mod(<<"fetch">>,
 get_mod(<<"failed-transport">>,
         <<"urn:xmpp:jingle:1">>) ->
     xep0166;
-get_mod(<<"abuse">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"state">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"utc">>, <<"urn:xmpp:time">>) -> xep0202;
@@ -1038,6 +1026,8 @@ get_mod(<<"enable">>, <<"urn:xmpp:sm:3">>) -> xep0198;
 get_mod(<<"size">>,
         <<"eu:siacs:conversations:http:upload">>) ->
     xep0363;
+get_mod(<<"text">>, <<"urn:xmpp:reporting:1">>) ->
+    xep0377;
 get_mod(<<"registration-required">>,
         <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -1085,8 +1075,6 @@ get_mod(<<"text">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"private">>, <<"urn:xmpp:carbons:2">>) ->
     xep0280;
-get_mod(<<"spam">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"show">>, <<"jabber:component:accept">>) ->
     rfc6120;
 get_mod(<<"PAGER">>, <<"vcard-temp">>) -> xep0054;
@@ -1277,6 +1265,9 @@ get_mod(<<"origin-id">>, <<"urn:xmpp:sid:0">>) ->
 get_mod(<<"note">>,
         <<"http://jabber.org/protocol/commands">>) ->
     xep0050;
+get_mod(<<"ephemeral">>,
+        <<"urn:xmpp:http:upload:purpose:0">>) ->
+    xep0363;
 get_mod(<<"message">>, <<"jabber:server">>) -> rfc6120;
 get_mod(<<"MIDDLE">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"activate">>,
@@ -1554,6 +1545,9 @@ get_mod(<<"request">>, <<"urn:xmpp:receipts">>) ->
 get_mod(<<"markable">>,
         <<"urn:xmpp:chat-markers:0">>) ->
     xep0333;
+get_mod(<<"permanent">>,
+        <<"urn:xmpp:http:upload:purpose:0">>) ->
+    xep0363;
 get_mod(<<"domain">>, <<"urn:xmpp:serverinfo:0">>) ->
     xep0485;
 get_mod(<<"url">>, <<"storage:bookmarks">>) -> xep0048;
@@ -1649,8 +1643,6 @@ get_mod(<<"software">>, <<"urn:xmpp:sasl:2">>) ->
 get_mod(<<"task-data">>, <<"urn:xmpp:sasl:2">>) ->
     xep0388;
 get_mod(<<"inline">>, <<"urn:xmpp:bind:0">>) -> xep0386;
-get_mod(<<"report">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"item-not-found">>,
         <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -1684,6 +1676,9 @@ get_mod(<<"reason">>,
         <<"urn:xmpp:message-moderate:0">>) ->
     xep0425;
 get_mod(<<"presence">>, <<"jabber:client">>) -> rfc6120;
+get_mod(<<"profile">>,
+        <<"urn:xmpp:http:upload:purpose:0">>) ->
+    xep0363;
 get_mod(<<"INTL">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"item">>,
         <<"http://jabber.org/protocol/muc#admin">>) ->
@@ -1764,6 +1759,19 @@ get_mod(<<"POSTAL">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"payload-too-big">>,
         <<"http://jabber.org/protocol/pubsub#errors">>) ->
     xep0060;
+get_mod(<<"presence-out">>, <<"jabber:iq:privacy">>) ->
+    xep0016;
+get_mod(<<"mechanism-too-weak">>,
+        <<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
+    rfc6120;
+get_mod(<<"improper-addressing">>,
+        <<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
+    rfc6120;
+get_mod(<<"r">>, <<"urn:xmpp:sm:3">>) -> xep0198;
+get_mod(<<"submission-id">>,
+        <<"urn:xmpp:mix:core:0">>) ->
+    xep0369;
+get_mod(<<"text">>, <<"urn:xmpp:sasl:2">>) -> xep0388;
 get_mod(Name, XMLNS) ->
     xmpp_codec_external:lookup(Name, XMLNS).
 
@@ -1796,6 +1804,7 @@ get_mod({block_list, _}) -> xep0191;
 get_mod({carbons_received, _}) -> xep0280;
 get_mod({carbons_sent, _}) -> xep0280;
 get_mod({origin_id, _}) -> xep0359;
+get_mod({upload_request_0, _, _, _, _, _}) -> xep0363;
 get_mod({hash_used, _}) -> xep0300;
 get_mod({x509_ca_list, _}) -> xep0417;
 get_mod({occupant_id, _}) -> xep0421;
@@ -1856,7 +1865,6 @@ get_mod({mam_archived, _, _}) -> xep0313;
 get_mod({mix_participant, _, _}) -> xep0369;
 get_mod({delegated, _, _}) -> xep0355;
 get_mod({text, _, _}) -> xep0234;
-get_mod({muc_hat, _, _}) -> xep0317;
 get_mod({scram_upgrade_salt, _, _}) -> xep0480;
 get_mod({xmpp_session, _}) -> rfc3921;
 get_mod({ping}) -> xep0199;
@@ -1981,6 +1989,7 @@ get_mod({offline_item, _, _}) -> xep0013;
 get_mod({db_verify, _, _, _, _, _, _}) -> xep0220;
 get_mod({upload_slot, _, _, _}) -> xep0363;
 get_mod({jingle_ibb_transport, _, _, _}) -> xep0261;
+get_mod({muc_hat, _, _, _}) -> xep0317;
 get_mod({message_moderated, _, _, _}) -> xep0425;
 get_mod({muc_decline, _, _, _}) -> xep0045;
 get_mod({sm_enable, _, _, _}) -> xep0198;
@@ -2016,7 +2025,6 @@ get_mod({compressed}) -> xep0138;
 get_mod({stream_error, _, _}) -> rfc6120;
 get_mod({inbox_entry, _, _, _}) -> xep0430;
 get_mod({receipt_request}) -> xep0184;
-get_mod({upload_request_0, _, _, _, _}) -> xep0363;
 get_mod({message_retracted_30, _, _, _, _}) -> xep0424;
 get_mod({privacy_item, _, _, _, _, _, _, _, _}) ->
     xep0016;
